@@ -22,9 +22,7 @@ def S3GetSession():
     return _s3,_bucket
 
 def S3SyncDownloadDataFrame(path,shm_name):
-    if os.environ['LOG_LEVEL']=='DEBUG':
-        Logger.log.debug('AWS S3 Sync DataFrame %s...' % (shm_name))    
-
+   
     npypath = (os.environ['DATABASE_FOLDER']+'\\'+str(shm_name)).replace('/','\\')+'.npy'
     success = S3Download(npypath)
     jsonpath = npypath.replace('.npy','.json')
@@ -38,8 +36,6 @@ def S3SyncDownloadDataFrame(path,shm_name):
     return success
 
 def S3SyncDownloadTimeSeries(path,shm_name):    
-    if os.environ['LOG_LEVEL']=='DEBUG':
-        Logger.log.debug('AWS S3 sync download timeseries %s...' % (shm_name))    
     tini = time.time()
     bucket_name = os.environ['S3_BUCKET'].replace('s3://','')
     s3,bucket = S3GetSession()
@@ -49,6 +45,8 @@ def S3SyncDownloadTimeSeries(path,shm_name):
     
     files = np.array([dbfolder+'\\'+obj_s.key.replace('/','\\')\
         for obj_s in bucket.objects.filter(Prefix=shm_name+'/')])
+    idx = ['shm_info.json' not in f for f in files]
+    files = files[idx]
     result = io_bound_process(S3DownloadThread,files,[s3])
 
     if success:
@@ -59,11 +57,10 @@ def S3SyncDownloadTimeSeries(path,shm_name):
     return success
 
 def S3SyncDownloadMetadata(pathpkl,name):    
-    if os.environ['LOG_LEVEL']=='DEBUG':
-        Logger.log.debug('AWS S3 Sync download metadata %s...' % (name))
-
-    success = S3Download(pathpkl)
+    
+    success = S3Download(str(pathpkl))
     success = (success) & (S3Download(str(pathpkl).replace('.pkl','.xlsx')))
+    success = (success) & (S3Download(str(pathpkl).replace('.pkl','_SYMBOLS.pkl')))
     
     if success:
         if os.environ['LOG_LEVEL']=='DEBUG':
@@ -98,7 +95,7 @@ def S3Download(local_path,s3=None):
         return True
 
     if isnewer or ischg:
-        try:
+        try:            
             obj.download_file(local_path)
             # update modification time
             remote_mtime_dt = datetime.fromtimestamp(remote_mtime)
@@ -106,7 +103,10 @@ def S3Download(local_path,s3=None):
             remote_mtime_local_tz = remote_mtime_dt+offset
             remote_mtime_local_tz_ts = remote_mtime_local_tz.timestamp()
             os.utime(local_path, (remote_mtime_local_tz_ts, remote_mtime_local_tz_ts))
-        except:
+            if os.environ['LOG_LEVEL']=='DEBUG':
+                Logger.log.debug('downloading metadata %s,%s DONE!' % (Logger.user,local_path))
+        except Exception as e:
+            Logger.log.error('downloading metadata %s,%s ERROR!\n%s' % (Logger.user,local_path,str(e)))
             return False
     return True
     
@@ -121,12 +121,9 @@ def S3Upload(localfilepath):
       
     trials = 3
     success=False
-    while trials>0:
-        if os.environ['LOG_LEVEL']=='DEBUG':
-            Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' ...')
+    while trials>0:        
         try:                
-            s3,bucket = S3GetSession()
-            
+            s3,bucket = S3GetSession()            
             mtime = os.path.getmtime(localfilepath)
             mtime_utc = datetime.utcfromtimestamp(mtime).timestamp()
             mtime_str = str(mtime_utc)
