@@ -31,15 +31,18 @@ class SharedDataFrame:
         self.database = self.sharedData.database
 
         self.period = sharedDataPeriod.period
-        self.periodSeconds = sharedDataPeriod.periodSeconds               
+        self.periodSeconds = sharedDataPeriod.periodSeconds  
+        
+        self.init_time = time.time()             
         
         # Time series dataframe
         self.data = pd.DataFrame()
-                        
+
+        self.create_map = 'na'
         if df is None: #Read dataset tag                                
             #allocate memory
-            isCreatedOrMapped = self.Malloc()
-            if not isCreatedOrMapped:
+            self.isCreatedOrMapped = self.Malloc()
+            if not self.isCreatedOrMapped:
                 if self.sharedData.s3read:
                     #Synchronize S3                
                     path, shm_name = self.getDataPath()
@@ -55,6 +58,8 @@ class SharedDataFrame:
             df = df._get_numeric_data().astype(np.float64)
             #allocate memory
             isCreate = self.Malloc(df=df)
+        
+        self.init_time = time.time() - self.init_time
 
     #GETTERS AND SETTERS
     def getDataPath(self):        
@@ -114,7 +119,7 @@ class SharedDataFrame:
                 if os.environ['LOG_LEVEL']=='DEBUG':
                     Logger.log.debug('Malloc create %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
                         (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
-
+                self.create_map = 'create'
                 return True
             except:
                 trymap=True
@@ -144,7 +149,8 @@ class SharedDataFrame:
                         self.data.loc[iidx, icol] = df.loc[iidx, icol].copy()
                     if os.environ['LOG_LEVEL']=='DEBUG':
                         Logger.log.debug('Malloc map %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
-                            (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))                    
+                            (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))       
+                    self.create_map = 'map'
                     return True
                 except:
                     return False
